# Farabio

## Setup
### Docker hub
```bash
# pull image
docker pull tuttelikz/farabio:2.0.0
# run container with gpu
docker run -d --gpus all -t tuttelikz/farabio:2.0.0 /bin/bash
```
- [Docker Hub](https://hub.docker.com/repository/docker/tuttelikz/farabio/general)